# Extender UI Script to add a grid with a finder and handling the insert key
###################################################################################################################################################
# Copyright 2023 Orchid Systems 
# -----------------------------
# Permitted for use with Orchid Systems Modules only.
# The code is supplied on an "as is" basis for training and demonstration purposes only and is not supported by Orchid Systems.
# If this code is deployed in a live production environment it is the responsibility of the End User to ensure 
# that it is operating as required.
###################################################################################################################################################

from accpac import *

class MyUI(UI):
	def __init__(self):
		UI.__init__(self)
		self.createScreen()

	def createScreen(self):
		self.title = "My Screen"
		self.onClose = self.btnClose_onClick

		layout = LayoutControl()

		g = self.addGrid("g")
		self.grid = g
		layout.addControl("g").setGrowWidth(True).setGrowHeight(True)
		g.addTextColumn("Name", "LEFT", 400, True, True).fieldName = "NAME"
		g.setOnKeyDown(self.grid_onKeyDown)
		g.setOnBeginEdit(self.grid_onBeginEdit)
		g.onFinder = self.grid_onFinder
		layout.addLine()

		layout.addSpacer() # this takes up any available space

		btn = self.addButton("btnClose", "Close")
		btn.onClick = self.btnClose_onClick
		layout.addControl("btnClose") # since we have a spacer, this will be pushed to the right
		btn.width = 1065

		self.setLayout(layout)

		self.show()

	def grid_onBeginEdit(self, e):
		rvspyTrace("grid_onBeginEdit " + e.fieldName)
		if e.fieldName == "NAME":
			e.datatype = "TEXT"
			e.width = 100

	def grid_onKeyDown(self, e):
		if e.key == 45:
			r = self.grid.addRow()
			self.grid.setRow(r)

	def grid_onFinder(self, fieldName, col, row):
		finder = Finder()
		finder.viewID = "IC0310"
		finder.returnFields = "1"
		finder.onOK = self.finder_ok
		finder.onCancel = self.finder_cancel
		finder.show(self)

	def finder_ok(self, e):
		self.grid.endEdit(e)

	def finder_cancel(self):
		self.grid.preventFinder()

	def btnClose_onClick(self):
		self.closeUI()

def main(args):
	MyUI()

